@@ -5,7 +5,7 @@ import static com.ibm.tools.attach.target.IPC.LOGGING_ENABLED;
 import static com.ibm.tools.attach.target.IPC.loggingStatus;
 
 /*******************************************************************************
- * Copyright (c) 2009, 2019 IBM Corp. and others
+ * Copyright (c) 2009, 2018 IBM Corp. and others
  *
  * This program and the accompanying materials are made available under
  * the terms of the Eclipse Public License 2.0 which accompanies this
@@ -465,7 +465,7 @@ public class AttachHandler extends Thread {
 					 * Therefore, notify myself 
 					 */
 					if (wakeHandler) {
-						CommonDirectory.notifyVm(1, true); 
+						CommonDirectory.notifyVm(1); 
 					}
 					destroySemaphore = true;
 				} else if (wakeHandler) {
@@ -477,7 +477,7 @@ public class AttachHandler extends Thread {
 					 * it wakes up.
 					 */
 					setDoCancelNotify(true); /* get the handler thread to close the semaphore */
-					CommonDirectory.notifyVm(numTargets, true); 
+					CommonDirectory.notifyVm(numTargets); 
 					/* CMVC 162086. add an extra notification since the count won't include this VM: the advertisement directory is already deleted */
 				}
 			} finally {
@@ -707,7 +707,7 @@ public class AttachHandler extends Thread {
 	 * or is shutting down
 	 * 
 	 */
-	public static boolean isAttachApiTerminated() {
+	static boolean isAttachApiTerminated() {
 		return (AttachStateValues.ATTACH_TERMINATED == getAttachState());
 	}
 
