@@ -134,7 +134,6 @@ module java.base {
     exports com.ibm.oti.util to
         java.management,
         jdk.attach,
-        jdk.jcmd,
         jdk.management,
         openj9.sharedclasses;
     exports com.ibm.oti.vm to
@@ -147,10 +146,7 @@ module java.base {
         java.management,
         java.rmi,
         openj9.sharedclasses;
-    exports com.ibm.tools.attach.target to
-        jdk.attach,
-        jdk.jcmd,
-        jdk.management;
+    exports com.ibm.tools.attach.target to jdk.attach;
     exports com.sun.security.ntlm to java.security.sasl;
     exports jdk.internal to jdk.jfr;
     exports jdk.internal.access to
@@ -237,10 +233,6 @@ module java.base {
     exports jdk.internal.vm.annotation to
         jdk.internal.vm.ci,
         jdk.unsupported;
-    exports openj9.management.internal to java.management;
-    exports openj9.tools.attach.diagnostics.base to
-        jdk.attach,
-        jdk.jcmd;
     exports sun.net to
         java.net.http,
         jdk.naming.dns;
